@@ -226,6 +226,8 @@ void DetailWindow::openMaps()
                addr.zipCode, addr.city);
     addr.country = country_;
 
+    //qDebug() << addr.street << addr.number << addr.zipCode << addr.city << addr.country;
+
     if(!maps.openMaps(addr))
     {
         QMaemo5InformationBox::information(this, tr("Unable to find coordinates for address."));
@@ -241,6 +243,7 @@ void DetailWindow::getDetails(QString& street, QString& streetNumber,
 
     QString streetVal = streetButton_->valueText();
     QString cityVal = cityButton_->valueText();
+    city = cityVal;
 
     QStringList words = streetVal.split(" ", QString::SkipEmptyParts);
 
@@ -270,7 +273,20 @@ void DetailWindow::getDetails(QString& street, QString& streetNumber,
         }
     }
 
+    if(streetNumber.isEmpty())
+    {
+        static QRegExp addrCheck(" ([0-9]+)");
+
+        if((pos = addrCheck.indexIn(street)) != -1)
+        {
+            streetNumber = addrCheck.cap(1);
+            street = street.left(pos);
+        }
+    }
+
     streetNumber = streetNumber.trimmed();
+    street = street.replace("Str.", QString::fromUtf8("Straße"));
+    street = street.replace("str.", QString::fromUtf8("straße"));
     street = street.trimmed();
 
     if((pos = cityVal.indexOf(" ")) > 0)
