@@ -20,6 +20,8 @@
 #define ENIROGUICONFIG_H
 
 #include <QtGui/QLineEdit>
+#include <QtGui/QVBoxLayout>
+#include <QtGui/QLabel>
 #include "buttonselector.h"
 #include "enirocoreconfig.h"
 #include "sourceguiconfig.h"
@@ -34,10 +36,17 @@ public:
     virtual ~EniroGuiConfig();
     virtual void save();
 
+private slots:
+    void siteChanged(unsigned int index, QString const& text, QVariant const& value);
+
 private:
+    void loadLayout(QString const& site);
+    QVBoxLayout* layout_;
     QLineEdit* usernameInput_;
     QLineEdit* passwordInput_;
     ButtonSelector* siteSelector_;
+    QLabel* usernameLabel_;
+    QLabel* passwordLabel_;
 
 };
 
