@@ -26,6 +26,8 @@
 #include "searchdialog.h"
 #include "settingsdialog.h"
 #include "aboutdialog.h"
+#include "source.h"
+#include "logwindow.h"
 
 class MainWindow : public QMainWindow
 {
@@ -37,12 +39,14 @@ public:
 
 signals:
     void search(SearchDialog::SearchDetails& details);
+    void logItemSelected(Source::Result const& result);
 
 public slots:
     void showSettings();
     void showAbout();
     void toggleDaemon();
     void openSearch();
+    void openLog();
     void handleSearch(SearchDialog::SearchDetails& details);
 
 private:
@@ -54,6 +58,7 @@ private:
     SearchDialog* searchDialog_;
     AboutDialog* aboutDialog_;
     QDialog* warning_;
+    LogWindow* logWindow_;
 
 };
 
